@@ -1,6 +1,6 @@
-__version__ = "0.3.0"
+__version__ = "0.5.0"
 
 from .backend import JSONBackend, PickleBackend
-from .exceptions import FakeItException, RecordNotFound
+from .exceptions import FakeItException, NotUniqueName, RecordNotFound
 from .fakeit import FakeIt
 from .models import Mode, Record
